@@ -39,7 +39,7 @@ from six.moves import html_entities
 from update_checker import update_check
 from warnings import simplefilter, warn_explicit
 
-__version__ = '2.0.14'
+__version__ = '2.0.15'
 UA_STRING = '%%s PRAW/%s Python/%s %s' % (__version__,
                                           sys.version.split()[0],
                                           platform.platform(True))
@@ -185,6 +185,7 @@ class Config(object):  # pylint: disable-msg=R0903
         self.domain = obj['domain']
         self.output_chars_limit = int(obj['output_chars_limit'])
         self.log_requests = int(obj['log_requests'])
+        self.http_proxy = obj.get('http_proxy') or None
         # We use `get(...) or None` because `get` may return an empty string
         self.client_id = obj.get('oauth_client_id') or None
         self.client_secret = obj.get('oauth_client_secret') or None
@@ -256,6 +257,8 @@ class BaseReddit(object):
         self.config = Config(site_name or os.getenv('REDDIT_SITE') or 'reddit')
         self.http = requests.session()
         self.http.headers['User-Agent'] = UA_STRING % user_agent
+        if self.config.http_proxy:
+            self.http.proxies = {'http': self.config.http_proxy}
         self.modhash = None
 
         # Check for updates if permitted and this is the first Reddit instance
