@@ -74,6 +74,11 @@ class Memoize(object):
                 if key in self._cache:
                     del self._cache[key]
 
+    def empty(self):
+        """Empty the entire cache."""
+        self._cache = {}
+        self._timeouts = {}
+
     def evict(self, urls):
         """Remove cached RedditContentObject by URL."""
         urls = [self.normalize_url(url) for url in urls]
@@ -279,18 +284,22 @@ def restrict_access(scope, mod=False, login=False, oauth_only=False):
     def wrap(function):
         @wraps(function)
         def wrapped(cls, *args, **kwargs):
-            def mods_all():
-                mod_subs = obj.user.get_cached_moderated_reddits()
-                for sub in six.text_type(subreddit).lower().split('+'):
-                    if sub not in mod_subs:
-                        return False
-                return True
+            def is_mod_of_all(user, subreddit):
+                mod_subs = user.get_cached_moderated_reddits()
+                subs = six.text_type(subreddit).lower().split('+')
+                return all(sub in mod_subs for sub in subs)
+
+            login_req = login and function.__name__ not in login_exceptions
+            mod_req = mod and function.__name__ not in moderator_exceptions
 
             # This segment of code uses hasattr to determine what instance type
             # the function was called on. We could use isinstance if we wanted
             # to import the types at runtime (decorators is used by all the
             # types).
-            if hasattr(cls, 'reddit_session'):
+            if cls is None:  # Occurs with (un)friend
+                assert login_req
+                raise errors.LoginRequired(function.__name__)
+            elif hasattr(cls, 'reddit_session'):
                 obj = cls.reddit_session
                 if mod:
                     if hasattr(cls, 'display_name'):  # Subreddit object
@@ -309,7 +318,6 @@ def restrict_access(scope, mod=False, login=False, oauth_only=False):
             # This function sets _use_oauth for one time use only.
             # Verify that statement is actually true.
             assert not obj._use_oauth  # pylint: disable-msg=W0212
-            login_req = login and function.__name__ not in login_exceptions
 
             if scope and obj.has_scope(scope):
                 obj._use_oauth = True  # pylint: disable-msg=W0212
@@ -320,14 +328,11 @@ def restrict_access(scope, mod=False, login=False, oauth_only=False):
                     # Now fetch the subreddit attribute. There is no good
                     # reason for it to not be set during a logged in session.
                     subreddit = cls.subreddit
-                if not mod or mod and obj.user.is_mod and mods_all():
-                    pass
-                elif function.__name__ not in moderator_exceptions:
+                if mod_req and not is_mod_of_all(obj.user, subreddit):
                     if scope:
                         raise errors.ModeratorOrScopeRequired(
                             function.__name__, scope)
-                    else:
-                        raise errors.ModeratorRequired(function.__name__)
+                    raise errors.ModeratorRequired(function.__name__)
             elif login_req:
                 if scope:
                     raise errors.LoginOrScopeRequired(function.__name__, scope)
