@@ -45,6 +45,11 @@ class RedditContentObject(object):
     @classmethod
     def from_api_response(cls, reddit_session, json_dict):
         """Return an instance of the appropriate class from the json_dict."""
+        if cls == WikiPage:  # Temporary HACK for WikiPage
+            parts = reddit_session._request_url.rsplit('/', 3)
+            subreddit = parts[1]
+            page = parts[3].split('.')[0]
+            return cls(reddit_session, subreddit, page, json_dict=json_dict)
         return cls(reddit_session, json_dict=json_dict)
 
     def __init__(self, reddit_session, json_dict=None, fetch=True,
@@ -119,6 +124,11 @@ class RedditContentObject(object):
                 json_dict = self._get_json_dict()
             else:
                 json_dict = {}
+
+        # TODO: Remove this wikipagelisting hack
+        if isinstance(json_dict, list):
+            json_dict = {'_tmp': json_dict}
+
         for name, value in six.iteritems(json_dict):
             if self._underscore_names and name in self._underscore_names:
                 name = '_' + name
@@ -912,6 +922,7 @@ class Subreddit(Messageable, Refreshable):
                 ('configure_flair', MFMix.configure_flair),
                 ('delete_flair', MFMix.delete_flair),
                 ('delete_image', MCMix.delete_image),
+                ('edit_wiki_page', AR.edit_wiki_page),
                 ('get_banned', MOMix.get_banned),
                 ('get_comments', UR.get_comments),
                 ('get_contributors', MOMix.get_contributors),
@@ -925,6 +936,10 @@ class Subreddit(Messageable, Refreshable):
                 ('get_spam', MOMix.get_spam),
                 ('get_stylesheet', MOMix.get_stylesheet),
                 ('get_unmoderated', MOMix.get_unmoderated),
+                ('get_wiki_banned', MOMix.get_wiki_banned),
+                ('get_wiki_contributors', MOMix.get_wiki_contributors),
+                ('get_wiki_page', UR.get_wiki_page),
+                ('get_wiki_pages', UR.get_wiki_pages),
                 ('set_flair', MFMix.set_flair),
                 ('set_flair_csv', MFMix.set_flair_csv),
                 ('set_settings', MCMix.set_settings),
@@ -935,14 +950,32 @@ class Subreddit(Messageable, Refreshable):
                 ('update_settings', MCMix.update_settings),
                 ('upload_image', MCMix.upload_image))
 
-    ban = _modify_relationship('banned', is_sub=True)
-    unban = _modify_relationship('banned', unlink=True, is_sub=True)
-    make_contributor = _modify_relationship('contributor', is_sub=True)
+    # Subreddit banned
+    add_ban = _modify_relationship('banned', is_sub=True)
+    ban = _modify_relationship('banned', is_sub=True, deprecated='add_ban')
+    unban = _modify_relationship('banned', unlink=True, is_sub=True,
+                                 deprecated='remove_ban')
+    remove_ban = _modify_relationship('banned', unlink=True, is_sub=True)
+    # Subreddit contributors
+    add_contributor = _modify_relationship('contributor', is_sub=True)
+    make_contributor = _modify_relationship('contributor', is_sub=True,
+                                            deprecated='add_contributor')
     remove_contributor = _modify_relationship('contributor', unlink=True,
                                               is_sub=True)
-    make_moderator = _modify_relationship('moderator', is_sub=True)
+    # Subreddit moderators
+    add_moderator = _modify_relationship('moderator', is_sub=True)
+    make_moderator = _modify_relationship('moderator', is_sub=True,
+                                          deprecated='add_moderator')
     remove_moderator = _modify_relationship('moderator', unlink=True,
                                             is_sub=True)
+    # Subreddit wiki banned
+    add_wiki_ban = _modify_relationship('wikibanned', is_sub=True)
+    remove_wiki_ban = _modify_relationship('wikibanned', unlink=True,
+                                           is_sub=True)
+    # Subreddit wiki contributors
+    add_wiki_contributor = _modify_relationship('wikicontributor', is_sub=True)
+    remove_wiki_contributor = _modify_relationship('wikicontributor',
+                                                   unlink=True, is_sub=True)
 
     # Generic listing selectors
     get_controversial = _get_sorter('controversial')
@@ -1000,7 +1033,7 @@ class Subreddit(Messageable, Refreshable):
         """Remove all user flair on this subreddit.
 
         :returns: The json response from the server when there is flair to
-        clear, otherwise returns None.
+            clear, otherwise returns None.
 
         """
         csv = [{'user': x['user']} for x in self.get_flair_list(limit=None)]
@@ -1019,34 +1052,91 @@ class Subreddit(Messageable, Refreshable):
         return self.reddit_session.search(query, self, *args, **kwargs)
 
 
-class UserList(RedditContentObject):
+class PRAWListing(RedditContentObject):
+
+    CHILD_ATTRIBUTE = None
+
+    """An abstract class to coerce a listing into RedditContentObjects."""
+
+    def __init__(self, reddit_session, json_dict=None, fetch=False):
+        super(PRAWListing, self).__init__(reddit_session, json_dict, fetch)
+
+        if not self.CHILD_ATTRIBUTE:
+            raise NotImplemented('PRAWListing must be extended.')
+
+        child_list = getattr(self, self.CHILD_ATTRIBUTE)
+        for i in range(len(child_list)):
+            child_list[i] = self._convert(reddit_session, child_list[i])
+
+    def __contains__(self, item):
+        return item in getattr(self, self.CHILD_ATTRIBUTE)
+
+    def __getitem__(self, index):
+        return getattr(self, self.CHILD_ATTRIBUTE)[index]
+
+    def __iter__(self):
+        return getattr(self, self.CHILD_ATTRIBUTE).__iter__()
+
+    def __len__(self):
+        return len(getattr(self, self.CHILD_ATTRIBUTE))
+
+    def __unicode__(self):
+        return six.text_type(getattr(self, self.CHILD_ATTRIBUTE))
+
+
+class UserList(PRAWListing):
 
     """A list of Redditors. Works just like a regular list."""
 
-    def __init__(self, reddit_session, json_dict=None, fetch=False):
-        super(UserList, self).__init__(reddit_session, json_dict, fetch)
+    CHILD_ATTRIBUTE = 'children'
 
-        # HACK: Convert children to Redditor instances
-        for i in range(len(self.children)):
-            tmp = self.children[i]
-            redditor = Redditor(reddit_session, tmp['name'], fetch=False)
-            redditor.id = tmp['id'].split('_')[1]  # pylint: disable-msg=C0103
-            self.children[i] = redditor
+    def _convert(self, reddit_session, data):
+        """Convert the data into a Redditor object."""
+        retval = Redditor(reddit_session, data['name'], fetch=False)
+        retval.id = data['id'].split('_')[1]
+        return retval
 
-    def __contains__(self, item):
-        return item in self.children
 
-    def __getitem__(self, index):
-        return self.children[index]
+class WikiPage(RedditContentObject):
 
-    def __iter__(self):
-        return self.children.__iter__()
+    """An individual WikiPage object."""
 
-    def __len__(self):
-        return len(self.children)
+    def __init__(self, reddit_session, subreddit=None, page=None,
+                 json_dict=None, fetch=True):
+        if not subreddit and not page:
+            subreddit = json_dict['sr']
+            page = json_dict['page']
+        info_url = reddit_session.config['wiki_page'] % (
+            six.text_type(subreddit), page)
+        super(WikiPage, self).__init__(reddit_session, json_dict, fetch,
+                                       info_url)
+        self.page = page
+        self.subreddit = subreddit
 
     def __unicode__(self):
-        return six.text_type(self.children)
+        return six.text_type('{0}:{1}').format(self.subreddit, self.page)
+
+    def edit(self, *args, **kwargs):
+        """Edit the wiki page.
+
+        :param content: The content to set the wiki page to.
+        :param reason: The justification for the edit (optional).
+
+        """
+        self.subreddit.edit_wiki_page(self.page, *args, **kwargs)
+
+
+class WikiPageListing(PRAWListing):
+
+    """A list of WikiPages. Works just like a regular list."""
+
+    CHILD_ATTRIBUTE = '_tmp'
+
+    def _convert(self, reddit_session, data):
+        """Convert the data into a WikiPage object."""
+        # TODO: The _request_url hack shouldn't be necessary
+        subreddit = reddit_session._request_url.rsplit('/', 4)[1]
+        return WikiPage(reddit_session, subreddit, data, fetch=False)
 
 
 def _add_aliases():
